summaryrefslogtreecommitdiff
path: root/fml/lib/FML/Command
diff options
context:
space:
mode:
authorfukachan <fukachan>2004-06-26 11:47:07 +0000
committerfukachan <fukachan>2004-06-26 11:47:07 +0000
commit8a4ad321fb933d12ba65adf4354b3fd8f4108981 (patch)
tree13c65285bd8bce940ed2dec2b6f350e5a043a517 /fml/lib/FML/Command
parent22d7fb5a6ff8d9ed3c0a3dcd5f27c1bfeb691137 (diff)
downloadfml8-8a4ad321fb933d12ba65adf4354b3fd8f4108981.tar.gz
fml8-8a4ad321fb933d12ba65adf4354b3fd8f4108981.tar.bz2
fml8-8a4ad321fb933d12ba65adf4354b3fd8f4108981.zip
fix comments.
change default: tail -100 by default.
Diffstat (limited to 'fml/lib/FML/Command')
-rw-r--r--fml/lib/FML/Command/Admin/log.pm12
1 files changed, 6 insertions, 6 deletions
diff --git a/fml/lib/FML/Command/Admin/log.pm b/fml/lib/FML/Command/Admin/log.pm
index 30ea55ec..5910153f 100644
--- a/fml/lib/FML/Command/Admin/log.pm
+++ b/fml/lib/FML/Command/Admin/log.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: log.pm,v 1.25 2004/02/01 14:39:00 fukachan Exp $
+# $FML: log.pm,v 1.26 2004/02/15 04:38:29 fukachan Exp $
#
package FML::Command::Admin::log;
@@ -15,7 +15,7 @@ use Carp;
=head1 NAME
-FML::Command::Admin::log - log file operations
+FML::Command::Admin::log - log file operations.
=head1 SYNOPSIS
@@ -45,7 +45,7 @@ sub new
}
-# Descriptions: need lock or not
+# Descriptions: need lock or not.
# Arguments: none
# Side Effects: none
# Return Value: NUM( 1 or 0)
@@ -69,7 +69,7 @@ sub process
}
-# Descriptions: show cgi menu
+# Descriptions: show cgi menu.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: update $member_map $recipient_map
# Return Value: none
@@ -99,9 +99,9 @@ sub _show_log
my $line_max = 0;
my $charset = $curproc->get_charset($is_cgi ? "cgi" : "log_file");
# run "tail -30 log" by default.
my $config = $curproc->config();
- my $last_n_lines = $config->{ log_command_tail_starting_location } || 30;
+ my $last_n_lines = $config->{ log_command_tail_starting_location } || 100;
use Mail::Message::Encode;
my $encode = new Mail::Message::Encode;
@@ -99,9 +99,9 @@ sub _show_log
my $line_max = 0;
my $charset = $curproc->get_charset($is_cgi ? "cgi" : "log_file");
- # run "tail -30 log" by default.
+ # run "tail -100 log" by default.
my $config = $curproc->config();